import sidebar from './sidebar';
import collect from './collect';
import { FETCH_START, FETCH_DONE } from './mutation-types';
const GET_WHITE_LIST = 'GET_WHITE_LIST';
const UPDATE_BACK_PAGE = 'UPDATE_BACK_PAGE';

let fetchCount = 0;
const state = () => ({
  loading: false,
  whiteList: [],
  dashboardBackPage: undefined,
});

const getters = {
  loading: state => state.loading,
  whiteList: state => state.whiteList,
  dashboardBackPage: state => state.dashboardBackPage,
};

const actions = {
  fetchStart({ commit }, notLoading) {
    commit(FETCH_START, notLoading);
  },
  fetchDone({ commit }, notLoading) {
    commit(FETCH_DONE, notLoading);
  },
  getWhiteList({ commit }, list) {
    commit(GET_WHITE_LIST, list);
  },
  updateBackPage({ commit }, name) {
    commit(UPDATE_BACK_PAGE, name);
  },
};
const mutations = {
  [FETCH_START](state, notLoading) {
    if (!notLoading) {
      fetchCount++;
      state.loading = true;
    }
  },
  [FETCH_DONE](state, notLoading) {
    if (!notLoading) {
      fetchCount--;
    }
    if (fetchCount === 0) {
      state.loading = false;
    }
  },
  [GET_WHITE_LIST](state, list) {
    state.whiteList = [...state.whiteList, ...list];
  },
  [UPDATE_BACK_PAGE](state, name) {
    state.dashboardBackPage = name;
  },
};
export default {
  modules: {
    sidebar,
    collect,
  },
  state,
  getters,
  actions,
  mutations,
};
